local coaf = require "coaf.core"
local _dbg = require "coaf.debug"
local periphery = require( "periphery" )

local _M = {
    gpio12 = nil, -- 模块为HDMI还是SDI。H：SDI  L：HDMI 高电平为SDI，低电平为HDMI
    gpio87 = nil, -- 模块为双模块板还是单模块板。L：SINGLE MODE  H：DOUBLE MODE 高为双模块，低为单模块
    gpio82 = nil, -- 模块在双模块底板上的位置。H：MODE1  L：MODE2 单模块是都为高电平，双模块时:高为模块1，低为模块2
    gpio86 = nil, -- 83-86为模块在机架上的位置,按数字顺序从低位到高位,1111为16，0000为1
    gpio85 = nil,
    gpio84 = nil,
    gpio83 = nil,
}

-- 获取当前设备视频源类型 HDMO or SDI
function _M.GetType()
    if not _M.gpio12 then
        local gpio12 = periphery.GPIO(12,"in")
        if gpio12 then
            _M.gpio12 = gpio12:read() and "SDI" or "HDMI"
        else
            _dbg.Error( "NM_DAEMON", "Could not open GPIO12 controller!" )
        end
    end
    return _M.gpio12 or "HDMI"
end

-- 获取当前设备时单模块还是双模块 DOUBLE:双模块，SINGLE:单模块
function _M.GetMode()
    if not _M.gpio87 then
        local gpio87 = periphery.GPIO(87,"in")
        if gpio87 then
            _M.gpio87 = gpio87:read() and "DOUBLE" or "SINGLE"
        else
            _dbg.Error( "NM_DAEMON", "Could not open GPIO87 controller!" )
        end
    end
    return _M.gpio87 or "SINGLE"
end

--获取在板子上位置 mode1 or mode2
function _M.GetLocation()
    if not _M.gpio82 then
        local gpio82 = periphery.GPIO(82,"in")
        if gpio82 then
            _M.gpio82 = gpio82:read() and "mode1" or "mode2"
        else
            _dbg.Error( "NM_DAEMON", "Could not open GPIO82 controller!" )
        end
    end
    return _M.gpio82 or "mode1"
end


-- 获取所在机架上的位置 1-16
function _M.GetRackLocation()
    if not _M.gpio83 or not _M.gpio84 or not _M.gpio85 or not _M.gpio86 then
        local gpio83,gpio84,gpio85,gpio86
        gpio83 = periphery.GPIO(83,"in")
        gpio84 = periphery.GPIO(84,"in")
        gpio85 = periphery.GPIO(85,"in")
        gpio86 = periphery.GPIO(86,"in")
        if gpio83 and gpio84 and gpio85 and gpio86 then
            _M.gpio83 = gpio83:read() and 1 or 0
            _M.gpio84 = gpio84:read() and 1 or 0
            _M.gpio85 = gpio85:read() and 1 or 0
            _M.gpio86 = gpio86:read() and 1 or 0
        else
            _M.gpio83,_M.gpio84,_M.gpio85,_M.gpio86=1,1,1,1
            _dbg.Error( "NM_DAEMON", "Could not open GPIO83 or GPIO84 or GPIO85 or GPIO86 controller!" )
        end
    end

    local location 
    location = ((_M.gpio83 or 1)*1 + (_M.gpio84 or 1)*2 + (_M.gpio85 or 1)*4 + (_M.gpio86 or 1)*8) +1
    return location
end

return _M

